/* -LICENSE-START-
** Copyright (c) 2018 Blackmagic Design
**
** Permission is hereby granted, free of charge, to any person or organization
** obtaining a copy of the software and accompanying documentation covered by
** this license (the "Software") to use, reproduce, display, distribute,
** execute, and transmit the Software, and to prepare derivative works of the
** Software, and to permit third-parties to whom the Software is furnished to
** do so, all subject to the following:
**
** The copyright notices in the Software and this entire statement, including
** the above license grant, this restriction and the following disclaimer,
** must be included in all copies of the Software, in whole or in part, and
** all derivative works of the Software, unless such copies or derivative
** works are solely in the form of machine-executable object code generated by
** a source language processor.
**
** THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
** IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
** FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
** SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
** FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
** ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
** DEALINGS IN THE SOFTWARE.
** -LICENSE-END-
*/
// ProfileCallback.h : header file
// DeckLink Device Profile Callback
//

#pragma once

#include "DeckLinkAPI.h"
#include "CapturePreview.h"

// Forward declarations
class CapturePreview;

class ProfileCallback : public IDeckLinkProfileCallback
{
private:
	CapturePreview*		m_uiDelegate;
	QAtomicInt			m_refCount;

public:
	ProfileCallback(CapturePreview* owner);
	virtual ~ProfileCallback() {}

	// IDeckLinkProfileCallback interface
	virtual HRESULT		STDMETHODCALLTYPE ProfileChanging(IDeckLinkProfile *profileToBeActivated, bool streamsWillBeForcedToStop);
	virtual HRESULT		STDMETHODCALLTYPE ProfileActivated(IDeckLinkProfile *activatedProfile);

	// IUnknown interface
	virtual HRESULT		STDMETHODCALLTYPE QueryInterface(REFIID iid, LPVOID *ppv);
	virtual ULONG		STDMETHODCALLTYPE AddRef();
	virtual ULONG		STDMETHODCALLTYPE Release();
};

class DeckLinkProfileCallbackEvent : public QEvent
{
private:
	IDeckLinkProfile* m_profile;

public:
	DeckLinkProfileCallbackEvent(QEvent::Type type, IDeckLinkProfile* profile)
		: QEvent(type), m_profile(profile) { m_profile->AddRef(); }
	virtual ~DeckLinkProfileCallbackEvent() { m_profile->Release(); }

	IDeckLinkProfile* Profile() const { return m_profile; }
};
